﻿using System;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Ink;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.ComponentModel;
using Microsoft.Practices.Composite.Events;
using SilverlightTestingDemo.Web;
using Microsoft.Practices.Composite.Presentation.Commands;
using CompanyModule.Events;

namespace CompanyModule.ViewModels
{
    public class EditCompanyViewModel : INotifyPropertyChanged, IEditCompanyViewModel
    {

        private IEventAggregator _eventAggregator;

        public EditCompanyViewModel(IEventAggregator eventAggregator)
        {
            _eventAggregator = eventAggregator;
            SaveCommand = new DelegateCommand<object>(OnSave);
        }

        private CompanyDomainContext _context;
        public CompanyDomainContext Context
        {
            get
            {
                return _context;
            }
            set
            {
                _context = value;
                OnPropertyCHanged("Context");
            }
        }

        private Company _company;
        public Company CurrentCompany
        {
            get
            {
                return _company;
            }
            set
            {
                _company = value;
                OnPropertyCHanged("CurrentCompany");

            }
        }

        public DelegateCommand<object> SaveCommand { get; private set; }
        private void OnSave(object payload)
        {
            _context.SubmitChanges((op) =>
                {
                    if (op.Error != null)
                    {
                        MessageBox.Show(op.Error.ToString());
                    }
                    else
                    {
                        MessageBox.Show("Saved");
                        _eventAggregator.GetEvent<CloseCompanyEvent>().Publish(true);
                    }
                }, null);
        }

        public event PropertyChangedEventHandler PropertyChanged;

        private void OnPropertyCHanged(string propertyName)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }

    }
}
